import { $props, defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/tree-menu/vue';
import Tree from '@opentinyvue/vue-tree';
import Input from '@opentinyvue/vue-input';
import { iconSearch, iconLeftWardArrow, iconEditorMenuLeft, iconEditorMenuRight } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/tree-menu/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var treeMenuProps = _extends({}, $props, {
  placeholder: {
    default: "",
    type: String
  },
  data: Array,
  nodeKey: String,
  defaultExpandAll: Boolean,
  suffixIcon: Object,
  searchIcon: {
    type: Object,
    default: function _default() {
      return iconSearch();
    }
  },
  props: Object,
  draggable: {
    type: Boolean,
    default: false
  },
  emptyText: {
    type: String,
    default: ""
  },
  checkStrictly: Boolean,
  lazy: {
    type: Boolean,
    default: false
  },
  load: Function,
  showCheckbox: Boolean,
  filterNodeMethod: Function,
  defaultCheckedKeys: Array,
  defaultExpandedKeys: Array,
  defaultExpandedKeysHighlight: [Number, String],
  indent: {
    type: Number,
    default: 16
  },
  allowDrag: Function,
  allowDrop: Function,
  expandOnClickNode: {
    type: Boolean,
    default: true
  },
  ellipsis: {
    type: Boolean,
    default: false
  },
  wrap: {
    type: Boolean,
    default: false
  },
  getMenuDataSync: Function,
  accordion: Boolean,
  showTitle: {
    type: Boolean,
    default: true
  },
  showFilter: {
    type: Boolean,
    default: true
  },
  showExpand: {
    type: Boolean,
    default: false
  },
  collapsible: {
    type: Boolean,
    default: true
  },
  showNumber: {
    type: Boolean,
    default: false
  },
  nodeHeight: Number,
  onlyCheckChildren: {
    type: Boolean,
    default: false
  },
  menuCollapsible: {
    type: Boolean,
    default: false
  },
  clearable: {
    type: Boolean,
    default: false
  },
  highlightQuery: {
    type: Boolean,
    default: false
  },
  // metaErp 新增属性
  widthAdapt: {
    type: Boolean,
    default: false
  }
});
var __vue2_script = defineComponent({
  name: $prefix + "TreeMenu",
  emits: ["change", "current-change", "node-drag-start", "node-drag-enter", "node-drag-over", "node-drag-end", "node-drop", "node-expand", "node-click", "check-change", "check", "collapse-change", "node-collapse"],
  components: {
    TinyTree: Tree,
    TinyInput: Input,
    IconArrow: iconLeftWardArrow(),
    IconEditorMenuLeft: iconEditorMenuLeft(),
    IconEditorMenuRight: iconEditorMenuRight()
  },
  props: treeMenuProps,
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api,
      mono: true
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-tree-menu",
    class: {
      "is-collapsed": _vm.state.isCollapsed,
      "is-expand": _vm.state.isExpand,
      "tiny-tree-menu__show-filter": _vm.showFilter,
      "tiny-tree-menu__show-expand": _vm.showExpand
    },
    style: _vm.widthAdapt ? {
      width: "100%"
    } : {}
  }, [_vm.menuCollapsible ? _c("div", {
    staticClass: "tiny-tree-menu__toggle-button",
    on: {
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.collapseChange.apply(null, arguments);
      }
    }
  }, [_c("icon-arrow")], 1) : _vm._e(), _vm.showFilter ? _c("tiny-input", {
    class: (_vm.state.isExpand || _vm.state.isCollapsed) && "is-hidden",
    attrs: {
      "placeholder": _vm.placeholder || _vm.t("ui.treeMenu.placeholder"),
      "prefix-icon": _vm.searchIcon,
      "clearable": _vm.state.clearable
    },
    model: {
      value: _vm.state.filterText,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "filterText", $$v);
      },
      expression: "state.filterText"
    }
  }) : _vm._e(), _c("tiny-tree", {
    ref: "tree",
    class: {
      "tiny-tree-menu__wrap": !_vm.ellipsis ? _vm.wrap : false,
      "tiny-tree-menu__overflow": _vm.ellipsis,
      "only-check-children": _vm.onlyCheckChildren
    },
    attrs: {
      "tiny_mode": "pc",
      "theme": "tiny",
      "accordion": _vm.accordion,
      "data": _vm.state.data,
      "node-key": _vm.nodeKey || "id",
      "empty-text": _vm.emptyText,
      "filter-node-method": _vm.filterNodeMethod || _vm.filterNode,
      "draggable": _vm.draggable,
      "default-expand-all": _vm.defaultExpandAll,
      "check-strictly": _vm.checkStrictly,
      "lazy": _vm.lazy,
      "load": _vm.load,
      "show-checkbox": _vm.showCheckbox,
      "show-number": _vm.showNumber,
      "collapsible": _vm.collapsible,
      "node-height": _vm.nodeHeight,
      "indent": _vm.indent,
      "default-checked-keys": _vm.defaultCheckedKeys,
      "default-expanded-keys": _vm.state.defaultExpandedKeys,
      "default-expanded-keys-highlight": _vm.defaultExpandedKeysHighlight,
      "allow-drag": _vm.allowDrag,
      "props": _vm.props,
      "allow-drop": _vm.allowDrop,
      "highlight-query": _vm.highlightQuery,
      "expand-on-click-node": _vm.expandOnClickNode,
      "only-check-children": _vm.onlyCheckChildren
    },
    on: {
      "node-drag-start": _vm.nodeDragStart,
      "node-drag-enter": _vm.nodeDragEnter,
      "node-drag-over": _vm.nodeDragOver,
      "node-drag-end": _vm.nodeDragEnd,
      "node-drop": _vm.nodeDrop,
      "node-expand": _vm.nodeExpand,
      "node-collapse": _vm.nodeCollapse,
      "node-click": _vm.nodeClick,
      "check-change": _vm.checkChange,
      "check": _vm.check,
      "current-change": _vm.currentChange
    },
    scopedSlots: _vm._u([{
      key: "default",
      fn: function fn(_ref) {
        var node = _ref.node, data = _ref.data;
        return [_c("div", {
          staticClass: "tree-node"
        }, [_c("div", {
          staticClass: "tree-menus-link tiny-tree-node__label"
        }, [_c("a", {
          staticClass: "tree-node-body",
          attrs: {
            "title": _vm.getTitle(data.label),
            "href": data.url || void 0
          }
        }, [_c("span", {
          staticClass: "tree-node-name"
        }, [!data.customIcon && _vm.suffixIcon ? _c(_vm.suffixIcon, {
          tag: "component"
        }) : _vm._e(), data.customIcon ? _c(data.customIcon, {
          tag: "component"
        }) : _vm._e(), _vm._t("default", function() {
          return [_vm._v(_vm._s(data.label || node.label) + " ")];
        }, {
          "node": node,
          "data": data,
          "label": data.label
        })], 2)])])])];
      }
    }], null, true)
  }), _vm.showExpand ? _c("div", {
    staticClass: "tiny-tree-menu__expand"
  }, [_c("span", [!_vm.state.isExpand ? _c("icon-editor-menu-left", {
    on: {
      "click": function click($event) {
        return _vm.handleToggleMenu("collapse");
      }
    }
  }) : _c("icon-editor-menu-right", {
    on: {
      "click": function click($event) {
        return _vm.handleToggleMenu("expand");
      }
    }
  })], 1)]) : _vm._e()], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var TreeMenu = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
TreeMenu.install = function(Vue) {
  Vue.component(TreeMenu.name, TreeMenu);
};
TreeMenu.version = version;

export { TreeMenu as default };
